package com.example.catchTheLetters.handler;

import com.example.catchTheLetters.entity.GameMessage;
import com.example.catchTheLetters.entity.PlayerInput;
import com.example.catchTheLetters.enums.MessageType;
import com.example.catchTheLetters.service.RoomService;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import jakarta.annotation.Resource;
import org.jetbrains.annotations.NotNull;
import org.springframework.stereotype.Controller;
import org.springframework.web.socket.TextMessage;
import org.springframework.web.socket.WebSocketSession;
import org.springframework.web.socket.handler.TextWebSocketHandler;

import java.io.IOException;

/**
 * WebSocket 处理器
 *
 * @author spyn
 */
@Controller
public class WebSocketHandler extends TextWebSocketHandler {

    private final ObjectMapper objectMapper = new ObjectMapper();

    @Resource
    private RoomService roomService;

    @Override
    public void handleTextMessage(@NotNull WebSocketSession session, TextMessage message) {
        // 处理接收到的消息
        GameMessage<?> gameMessage;
        try {
            gameMessage = objectMapper.readValue(message.getPayload(), GameMessage.class);
        } catch (JsonProcessingException e) {
            roomService.sendMessage(session, new GameMessage<>(MessageType.ERROR, "消息解析失败"));
            return;
        }

        switch (gameMessage.getType()) {
            case INPUT:
                // 处理输入消息
                roomService.handleInput(gameMessage.getRoomId(), session, (PlayerInput) gameMessage.getData());
                break;
            case ROOM:
                // 处理房间消息
                break;
            case LETTER:
                // 处理字母消息
                break;
            case SCORE:
                // 处理分数消息
                break;
            case HEALTH:
                // 处理生命值消息
                break;
            default:
                roomService.sendMessage(session, new GameMessage<>(MessageType.ERROR, "未知的消息类型"));
        }
    }
}
